@@ -21,7 +21,7 @@ import shutil
 from calculate.lib.utils.files import (listDirectory, readFile, readLinesFile,
                                        makeDirectory, removeDir)
 from calculate.lib.utils.git import Git
-from update import UpdateError
+from .update import UpdateError
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_update3', sys.modules[__name__])
@@ -209,7 +209,7 @@ class ProfileRepository(object):
         if git.is_private_url(url):
             try:
                 makeDirectory(rpath)
-                os.chmod(rpath, 0700)
+                os.chmod(rpath, 0o700)
             except OSError:
                 pass
         git.cloneRepository(url, rpath, branch)
