@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,6 @@
 
 import os
 from os import path
-from itertools import ifilter
 from calculate.core.datavars import DataVarsCore
 from calculate.core.server.gen_pid import search_worked_process
 from calculate.lib.cl_template import SystemIni
@@ -28,8 +27,7 @@ class UpdateInfo(object):
     """
     Информационный объект о процессе обновления
     """
-    section = "update"
-    varname = "updates"
+    update_file = "/var/lib/calculate/calculate-update/updates.available"
 
     def __init__(self, dv=None):
         if dv is None:
@@ -46,15 +44,20 @@ class UpdateInfo(object):
         """
         Проверить есть ли обновления по ini.env
         """
-        return SystemIni().getVar(cls.section, cls.varname) == u'on'
+        return path.exists(cls.update_file)
 
     @classmethod
     def set_update_ready(cls, value):
         """
         Установить статус обновления
         """
-        SystemIni().setVar(cls.section,
-            {cls.varname:"on" if value else "off"})
+        try:
+            if value:
+                writeFile(cls.update_file).close()
+            else:
+                os.unlink(cls.update_file)
+        except OSError:
+            pass
 
     def check_for_dispatch(self):
         """
@@ -67,7 +70,7 @@ class UpdateInfo(object):
         """
         Проверить есть ли уже запущенная копия console-gui
         """
-        return any(ifilter(lambda x: "cl-console-gui" in x, getRunCommands()))
+        return any(filter(lambda x: "cl-console-gui" in x, getRunCommands()))
 
     def update_already_run(self):
         """
